Installing Promus — promus 0.1.0 documentation

# Installing Promus

The easiest way to install promus is to use `pip`. If you wish to perform a global installation and you have admin rights then do

    sudo pip install promus

or to install in some directory under your user account

    pip install --user promus

If you prefer to do the installation manually then from the command line you may do the following (where x.y is the version number):

    wget https://pypi.python.org/packages/source/p/promus/promus-x.y.tar.gz
    tar xvzf promus-x.y.tar.gz
    cd promus-x.y/
    sudo python setup.py install

The last command can be replaced by `python setup.py install --user`. See PyPI for all available versions.

Once you have finished do the installation you need to set up your `$PATH` so that your shell may look for it. If you are using `bash` you can call the `install` command from promus:

    python -m promus install

## Git

Promus was designed with one goal in mind: to make `git` available in your own server without administrator rights. For this reason, before you even think about using promus you must obtain a copy of `git` which you can obtain at http://git-scm.com/downloads.

Make sure that `git` is installed in your system before proceding with the next section.

## Setting up promus

If you completed the previous sections then you are well on your way to creating your first private repositories or to connect to one. First you need to let promus and git some information about yourself.

    $ promus setup
    Full name:
    E-mail address:
    Hostname alias:
    Host e-mail:
    Password:

Keep in mind that if you are not going to use your personal computer to create repositories then there is no need to provide a `Host e-mail` nor a `Password`. What is important however, is that you provide a `Hostname alias`. The alias will be helpful to identify the machine from where you provided commands.

If you are setting up promus to create repositories and your server provides you with an e-mail address then you are allowed to ommit entering your password since the system can authenticate you when you `ssh` to the server.

To make sure that the email you provided for the host is working you can use the `verify` command to make promus send you an email.

    $ promus verify
    sending email ... done

At this point you should be ready to start using promus.

Note

Make sure to use only one e-mail address in all the machines you are using. This will help with the identification of users even if you have different usernames in different machines.